@@ -18,7 +18,7 @@ class DlgAnnotations : public QWidget
     Q_OBJECT
 
     public:
-        explicit DlgAnnotations( QWidget * parent = Q_NULLPTR );
+        explicit DlgAnnotations( QWidget * parent = nullptr );
 };
 
 #endif
