@@ -32,6 +32,9 @@ class AnnotationPrivate
 
         virtual ~AnnotationPrivate();
 
+        AnnotationPrivate(const AnnotationPrivate &) = delete;
+        AnnotationPrivate &operator=(const AnnotationPrivate &) = delete;
+
         /**
          * Transforms the annotation coordinates with the transformation
          * defined by @p matrix.
@@ -53,7 +56,7 @@ class AnnotationPrivate
          * given point @p x @p y @p xScale @p yScale
          * @since 0.17
          */
-        virtual double distanceSqr( double x, double y, double xScale, double yScale );
+        virtual double distanceSqr( double x, double y, double xScale, double yScale ) const;
 
         PagePrivate * m_page;
 
