@@ -36,6 +36,7 @@ using namespace Okular;
 
 class OkularBookmarkAction : public KBookmarkAction
 {
+    Q_OBJECT
     public:
         OkularBookmarkAction( const Okular::DocumentViewport& vp, const KBookmark& bk, KBookmarkOwner* owner, QObject *parent )
             : KBookmarkAction( bk, owner, parent )
@@ -106,6 +107,9 @@ class BookmarkManager::Private : public KBookmarkOwner
             // delete manager;
         }
 
+        Private(const Private &) = delete;
+        Private &operator=(const Private &) = delete;
+
         QUrl currentUrl() const override;
         QString currentTitle() const override;
         bool enableOption(BookmarkOption option) const override;
@@ -145,8 +149,9 @@ BookmarkManager::BookmarkManager( DocumentPrivate * document )
     d->manager = KBookmarkManager::managerForFile( d->file, QStringLiteral("okular") );
     d->manager->setEditorOptions( QGuiApplication::applicationDisplayName(), false );
     d->manager->setUpdate( true );
-    connect( d->manager, SIGNAL(changed(QString,QString)),
-             this, SLOT(_o_changed(QString,QString)) );
+    connect( d->manager, &KBookmarkManager::changed, this, [this](const QString & groupAddress, const QString & caller) {
+        d->_o_changed(groupAddress, caller);
+    });
 }
 
 BookmarkManager::~BookmarkManager()
@@ -281,7 +286,7 @@ KBookmark::List BookmarkManager::bookmarks( int page ) const
 {
     const KBookmark::List bmarks = bookmarks();
     KBookmark::List ret;
-    foreach( const KBookmark &bm, bmarks )
+    for ( const KBookmark &bm : bmarks )
     {
         DocumentViewport vp( bm.url().fragment(QUrl::FullyDecoded) );
         if ( vp.isValid() && vp.pageNumber == page )
@@ -296,7 +301,7 @@ KBookmark::List BookmarkManager::bookmarks( int page ) const
 KBookmark BookmarkManager::bookmark( int page ) const
 {
     const KBookmark::List bmarks = bookmarks();
-    foreach( const KBookmark &bm, bmarks )
+    for ( const KBookmark &bm : bmarks )
     {
         DocumentViewport vp( bm.url().fragment(QUrl::FullyDecoded) );
         if ( vp.isValid() && vp.pageNumber == page )
@@ -386,12 +391,12 @@ QHash<QUrl, QString>::iterator BookmarkManager::Private::bookmarkFind( const QUr
     return it;
 }
 
-void BookmarkManager::addBookmark( int n )
+void BookmarkManager::addBookmark( int page )
 {
-    if ( n >= 0 && n < (int)d->document->m_pagesVector.count() )
+    if ( page >= 0 && page < (int)d->document->m_pagesVector.count() )
     {
-        if ( setPageBookmark( n ) )
-            foreachObserver( notifyPageChanged( n, DocumentObserver::Bookmark ) );
+        if ( setPageBookmark( page ) )
+            foreachObserver( notifyPageChanged( page, DocumentObserver::Bookmark ) );
     }
 }
 
@@ -460,12 +465,12 @@ bool BookmarkManager::addBookmark(const QUrl &referurl, const Okular::DocumentVi
     return true;
 }
 
-void BookmarkManager::removeBookmark( int n )
+void BookmarkManager::removeBookmark( int page )
 {
-    if ( n >= 0 && n < (int)d->document->m_pagesVector.count() )
+    if ( page >= 0 && page < (int)d->document->m_pagesVector.count() )
     {
-        if ( removePageBookmark( n ) )
-            foreachObserver( notifyPageChanged( n, DocumentObserver::Bookmark ) );
+        if ( removePageBookmark( page ) )
+            foreachObserver( notifyPageChanged( page, DocumentObserver::Bookmark ) );
     }
 }
 
@@ -552,7 +557,7 @@ void BookmarkManager::removeBookmarks(const QUrl &referurl, const KBookmark::Lis
 
     const QHash<int,int> oldUrlBookmarks = d->urlBookmarks;
     bool deletedAny = false;
-    foreach ( const KBookmark & bm, list )
+    for ( const KBookmark &bm : list )
     {
         if ( bm.parentGroup() == thebg )
         {
@@ -708,7 +713,7 @@ KBookmark BookmarkManager::nextBookmark( const DocumentViewport &viewport) const
     std::sort(bmarks.begin(), bmarks.end(), bookmarkLessThan);
 
     KBookmark bookmark;
-    foreach ( const KBookmark &bm, bmarks )
+    for ( const KBookmark &bm : qAsConst(bmarks) )
     {
         DocumentViewport vp( bm.url().fragment(QUrl::FullyDecoded) );
         if ( viewport < vp )
@@ -744,6 +749,6 @@ KBookmark BookmarkManager::previousBookmark( const DocumentViewport &viewport )
 #undef foreachObserver
 #undef foreachObserverD
 
-#include "moc_bookmarkmanager.cpp"
+#include "bookmarkmanager.moc"
 
 /* kate: replace-tabs on; indent-width 4; */
