@@ -28,8 +28,8 @@ PageController::~PageController()
 
 void PageController::addRotationJob(RotationJob *job)
 {
-    connect( job, SIGNAL(done(ThreadWeaver::JobPointer)),
-             this, SLOT(imageRotationDone(ThreadWeaver::JobPointer)) );
+    connect( job, &RotationJob::done,
+             this, &PageController::imageRotationDone );
     ThreadWeaver::enqueue(&m_weaver, job);
 }
 
@@ -44,5 +44,3 @@ void PageController::imageRotationDone(const ThreadWeaver::JobPointer &j)
         emit rotationFinished( job->page()->m_number, job->page()->m_page );
     }
 }
-
-#include "moc_pagecontroller_p.cpp"
