@@ -24,7 +24,7 @@ class glyph;
 class TeXFont_PFB : public TeXFont {
  public:
   TeXFont_PFB(TeXFontDefinition *parent, fontEncoding *enc=nullptr, double slant=0.0 );
-  ~TeXFont_PFB();
+  ~TeXFont_PFB() override;
 
   glyph* getGlyph(quint16 character, bool generateCharacterPixmap=false, const QColor& color=Qt::black) override;
 
