@@ -19,9 +19,10 @@
 namespace Mobi {
   class Converter : public Okular::TextDocumentConverter
     {
+        Q_OBJECT
     public:
       Converter();
-      ~Converter();
+      ~Converter() override;
       
       QTextDocument *convert( const QString &fileName ) override;
     private:
