@@ -10,30 +10,14 @@
 
 #include "converter.h"
 
-#include <kaboutdata.h>
+#include <KAboutData>
 #include <kconfigdialog.h>
+#include <KLocalizedString>
 
-static KAboutData createAboutData()
-{
-  KAboutData aboutData(
-                       "okular_mobi",
-                       "okular_mobi",
-                       ki18n("Mobipocket Backend"),
-                       "0.1.1",
-                       ki18n("A mobipocket backend"),
-                       KAboutData::License_GPL,
-                       ki18n("© 2008-2009 Jakub Stachowski")
-                       );
-  aboutData.addAuthor(ki18n("Jakub Stachowski"), KLocalizedString(),
-                      "qbast@go2.pl");
-
-  return aboutData;
-}
-
-OKULAR_EXPORT_PLUGIN( MobiGenerator, createAboutData() )
+OKULAR_EXPORT_PLUGIN(MobiGenerator, "libokularGenerator_mobi.json")
 
 MobiGenerator::MobiGenerator( QObject *parent, const QVariantList &args )
-: Okular::TextDocumentGenerator( new Mobi::Converter, "okular_mobi_generator_settings", parent, args )
+: Okular::TextDocumentGenerator( new Mobi::Converter, QStringLiteral("okular_mobi_generator_settings"), parent, args )
 {
 }
 
@@ -41,5 +25,7 @@ void MobiGenerator::addPages( KConfigDialog* dlg )
 {
     Okular::TextDocumentSettingsWidget *widget = new Okular::TextDocumentSettingsWidget();
 
-    dlg->addPage( widget, generalSettings(), i18n("Mobipocket"), "application-x-mobipocket-ebook", i18n("Mobipocket Backend Configuration") );
+    dlg->addPage( widget, generalSettings(), i18n("Mobipocket"), QStringLiteral("application-x-mobipocket-ebook"), i18n("Mobipocket Backend Configuration") );
 }
+
+#include "generator_mobi.moc"
