@@ -30,8 +30,8 @@ struct GSRendererThreadRequest
 {
     GSRendererThreadRequest(GSGenerator *_owner)
         : owner(_owner)
-        , request(0)
-        , spectrePage(0)
+        , request(nullptr)
+        , spectrePage(nullptr)
         , textAAbits(1)
         , graphicsAAbits(1)
         , magnify(1.0)
@@ -56,7 +56,7 @@ Q_OBJECT
     public:
         static GSRendererThread *getCreateRenderer();
 
-        ~GSRendererThread();
+        ~GSRendererThread() override;
 
         void addRequest(const GSRendererThreadRequest &req);
 
