@@ -251,7 +251,7 @@ QImage TIFFGenerator::image( Okular::PixmapRequest * request )
             orientation = ORIENTATION_TOPLEFT;
 
         QImage image( width, height, QImage::Format_RGB32 );
-        uint32 * data = (uint32 *)image.bits();
+        uint32 * data = reinterpret_cast<uint32 *>(image.bits());
 
         // read data
         if ( TIFFReadRGBAImageOriented( d->tiff, width, height, data, orientation ) != 0 )
@@ -379,7 +379,7 @@ bool TIFFGenerator::print( QPrinter& printer )
                                                          document()->currentPage() + 1,
                                                          document()->bookmarkedPageList() );
 
-    for ( tdir_t i = 0; i < pageList.count(); ++i )
+    for ( int i = 0; i < pageList.count(); ++i )
     {
         if ( !TIFFSetDirectory( d->tiff, mapPage( pageList[i] - 1 ) ) )
             continue;
@@ -389,18 +389,18 @@ bool TIFFGenerator::print( QPrinter& printer )
             continue;
 
         QImage image( width, height, QImage::Format_RGB32 );
-        uint32 * data = (uint32 *)image.bits();
+        uint32 * data = reinterpret_cast<uint32 *>(image.bits());
 
         // read data
         if ( TIFFReadRGBAImageOriented( d->tiff, width, height, data, ORIENTATION_TOPLEFT ) != 0 )
         {
             // an image read by ReadRGBAImage is ABGR, we need ARGB, so swap red and blue
             uint32 size = width * height;
-            for ( uint32 i = 0; i < size; ++i )
+            for ( uint32 j = 0; j < size; ++j )
             {
-                uint32 red = ( data[i] & 0x00FF0000 ) >> 16;
-                uint32 blue = ( data[i] & 0x000000FF ) << 16;
-                data[i] = ( data[i] & 0xFF00FF00 ) + red + blue;
+                uint32 red = ( data[j] & 0x00FF0000 ) >> 16;
+                uint32 blue = ( data[j] & 0x000000FF ) << 16;
+                data[j] = ( data[j] & 0xFF00FF00 ) + red + blue;
             }
         }
 
