@@ -47,6 +47,11 @@ static bool attachExistingInstance(const QStringList &paths, const QString &seri
     if ( paths.count() < 1 )
         return false;
 
+    // Don't try to attach to an existing instance with --print-and-exit because that would mean
+    // we're going to exit that other instance and that's just rude
+    if ( ShellUtils::showPrintDialogAndExit(serializedOptions) )
+        return false;
+
     const QStringList services = QDBusConnection::sessionBus().interface()->registeredServiceNames().value();
 
     // Don't match the service without trailing "-" (unique instance)
@@ -109,7 +114,7 @@ static bool attachExistingInstance(const QStringList &paths, const QString &seri
         // Returns false if it can't fit another document
         const QDBusReply<bool> reply = bestService->call( QStringLiteral("openDocument"), path, serializedOptions );
         if( !reply.isValid() || !reply.value() )
-        return false;
+            return false;
     }
 
     bestService->call( QStringLiteral("tryRaise") );
