@@ -171,7 +171,19 @@ bool Shell::eventFilter(QObject *obj, QEvent *event)
         dEvent->setAccepted(true);
         return true;
     }
-    return false;
+
+    // Handle middle button click events on the tab bar
+    if (obj == m_tabWidget && event->type() == QEvent::MouseButtonRelease) {
+        QMouseEvent* mEvent = static_cast<QMouseEvent*>(event);
+        if (mEvent->button() == Qt::MiddleButton) {
+            int tabIndex = m_tabWidget->tabBar()->tabAt(mEvent->pos());
+            if (tabIndex != -1) {
+                closeTab(tabIndex);
+                return true;
+            }
+        }
+    }
+    return KParts::MainWindow::eventFilter(obj, event);
 }
 
 bool Shell::isValid() const
@@ -189,9 +201,9 @@ Shell::~Shell()
     if( !m_tabs.empty() )
     {
         writeSettings();
-        for( QList<TabState>::iterator it = m_tabs.begin(); it != m_tabs.end(); ++it )
+        for( const TabState &tab : qAsConst( m_tabs ) )
         {
-           it->part->closeUrl( false );
+           tab.part->closeUrl( false );
         }
         m_tabs.clear();
     }
@@ -292,7 +304,10 @@ void Shell::openUrl( const QUrl & url, const QString &serializedOptions )
                     m_recent->addUrl( url );
                 }
                 else
+                {
                     m_recent->removeUrl( url );
+                    closeTab( activeTab );
+                }
             }
         }
     }
@@ -362,6 +377,13 @@ void Shell::setupActions()
   actionCollection()->setDefaultShortcuts(m_prevTabAction, KStandardShortcut::tabPrev());
   m_prevTabAction->setEnabled( false );
   connect( m_prevTabAction, &QAction::triggered, this, &Shell::activatePrevTab );
+
+  m_undoCloseTab = actionCollection()->addAction(QStringLiteral("undo-close-tab"));
+  m_undoCloseTab->setText( i18n("Undo close tab") );
+  actionCollection()->setDefaultShortcut(m_undoCloseTab, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_T));
+  m_undoCloseTab->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")));
+  m_undoCloseTab->setEnabled( false );
+  connect( m_undoCloseTab, &QAction::triggered, this, &Shell::undoCloseTab );
 }
 
 void Shell::saveProperties(KConfigGroup &group)
@@ -371,9 +393,9 @@ void Shell::saveProperties(KConfigGroup &group)
 
     // Gather lists of settings to preserve
     QStringList urls;
-    for( int i = 0; i < m_tabs.size(); ++i )
+    for( const TabState &tab : qAsConst( m_tabs ) )
     {
-        urls.append( m_tabs[i].part->url().url() );
+        urls.append( tab.part->url().url() );
     }
     group.writePathEntry( SESSION_URL_KEY, urls );
     group.writeEntry( SESSION_TAB_KEY, m_tabWidget->currentIndex() );
@@ -447,7 +469,7 @@ void Shell::fileOpen()
     QMimeDatabase mimeDatabase;
     QSet<QString> globPatterns;
     QMap<QString, QStringList> namedGlobs;
-    foreach ( const QString &mimeName, m_fileformats ) {
+    for ( const QString &mimeName : qAsConst(m_fileformats) ) {
         QMimeType mimeType = mimeDatabase.mimeTypeForName( mimeName );
         const QStringList globs( mimeType.globPatterns() );
         if ( globs.isEmpty() ) {
@@ -460,21 +482,21 @@ void Shell::fileOpen()
 
     }
     QStringList namePatterns;
-    foreach( const QString &name, namedGlobs.keys()) {
-        namePatterns.append( name +
-                             QStringLiteral(" (") +
-                             namedGlobs[name].join( QLatin1Char(' ') ) +
-                             QStringLiteral(")")
+    for ( auto it = namedGlobs.cbegin(); it != namedGlobs.cend(); ++it ) {
+        namePatterns.append( it.key() + QLatin1String(" (")
+                             + it.value().join( QLatin1Char(' ') ) + QLatin1Char(')')
                            );
     }
 
+    const QStringList allGlobPatterns = globPatterns.values();
     namePatterns.prepend( i18n("All files (*)") );
-    namePatterns.prepend( i18n("All supported files (%1)", globPatterns.toList().join( QLatin1Char(' ') ) ) );
+    namePatterns.prepend( i18n("All supported files (%1)", allGlobPatterns.join( QLatin1Char(' ') ) ) );
     dlg->setNameFilters( namePatterns );
 
     dlg->setWindowTitle( i18n("Open Document") );
     if ( dlg->exec() && dlg ) {
-        foreach(const QUrl& url, dlg->selectedUrls())
+        const QList<QUrl> urlList = dlg->selectedUrls();
+        for (const QUrl &url : urlList)
         {
             openUrl( url );
         }
@@ -628,6 +650,7 @@ void Shell::setActiveTab( int tab )
 void Shell::closeTab( int tab )
 {
     KParts::ReadWritePart* const part = m_tabs[tab].part;
+    QUrl url = part->url();
     if( part->closeUrl() && m_tabs.count() > 1 )
     {
         if( part->factory() )
@@ -636,6 +659,8 @@ void Shell::closeTab( int tab )
         part->deleteLater();
         m_tabs.removeAt( tab );
         m_tabWidget->removeTab( tab );
+        m_undoCloseTab->setEnabled( true );
+        m_closedTabUrls.append( url );
 
         if( m_tabWidget->count() == 1 )
         {
@@ -673,9 +698,15 @@ void Shell::openNewTab( const QUrl& url, const QString &serializedOptions )
     setActiveTab( m_tabs.size() - 1 );
 
     if( part->openUrl(url) )
+    {
         m_recent->addUrl( url );
+    }
     else
+    {
         setActiveTab( previousActiveTab );
+        closeTab( m_tabs.size() - 1 );
+        m_recent->removeUrl( url );
+    }
 }
 
 void Shell::applyOptionsToPart( QObject* part, const QString &serializedOptions )
@@ -689,17 +720,18 @@ void Shell::applyOptionsToPart( QObject* part, const QString &serializedOptions
     if ( ShellUtils::showPrintDialogAndExit(serializedOptions) )
         QMetaObject::invokeMethod( part, "enableExitAfterPrint" );
     if(!find.isEmpty())
-        QMetaObject::invokeMethod( part, "enableStartWithFind", Q_ARG( const QString &, find ));
+        QMetaObject::invokeMethod( part, "enableStartWithFind", Q_ARG(QString, find ));
 }
 
 void Shell::connectPart( QObject* part )
 {
-    connect( this, SIGNAL(moveSplitter(int)), part, SLOT(moveSplitter(int)) );
-    connect( part, SIGNAL(enablePrintAction(bool)), this, SLOT(setPrintEnabled(bool)));
-    connect( part, SIGNAL(enableCloseAction(bool)), this, SLOT(setCloseEnabled(bool)));
-    connect( part, SIGNAL(mimeTypeChanged(QMimeType)), this, SLOT(setTabIcon(QMimeType)));
-    connect( part, SIGNAL(urlsDropped(QList<QUrl>)), this, SLOT(handleDroppedUrls(QList<QUrl>)) );
-    connect( part, SIGNAL(fitWindowToPage(QSize,QSize)), this, SLOT(slotFitWindowToPage(QSize,QSize)) );
+    // We're abusing the fact we know the part is our part here
+    connect( this, SIGNAL(moveSplitter(int)), part, SLOT(moveSplitter(int)) );                              // clazy:exclude=old-style-connect
+    connect( part, SIGNAL(enablePrintAction(bool)), this, SLOT(setPrintEnabled(bool)));                     // clazy:exclude=old-style-connect
+    connect( part, SIGNAL(enableCloseAction(bool)), this, SLOT(setCloseEnabled(bool)));                     // clazy:exclude=old-style-connect
+    connect( part, SIGNAL(mimeTypeChanged(QMimeType)), this, SLOT(setTabIcon(QMimeType)));                  // clazy:exclude=old-style-connect
+    connect( part, SIGNAL(urlsDropped(QList<QUrl>)), this, SLOT(handleDroppedUrls(QList<QUrl>)) );          // clazy:exclude=old-style-connect
+    connect( part, SIGNAL(fitWindowToPage(QSize,QSize)), this, SLOT(slotFitWindowToPage(QSize,QSize)) );    // clazy:exclude=old-style-connect
 }
 
 void Shell::print()
@@ -751,6 +783,23 @@ void Shell::activatePrevTab()
     setActiveTab( prevTab );
 }
 
+void Shell::undoCloseTab()
+{
+    if ( m_closedTabUrls.isEmpty() )
+    {
+        return;
+    }
+
+    const QUrl lastTabUrl = m_closedTabUrls.takeLast();
+
+    if ( m_closedTabUrls.isEmpty() )
+    {
+        m_undoCloseTab->setEnabled(false);
+    }
+
+    openUrl(lastTabUrl);
+}
+
 void Shell::setTabIcon( const QMimeType& mimeType )
 {
     int i = findTabIndex( sender() );
@@ -774,7 +823,7 @@ int Shell::findTabIndex( QObject* sender )
 
 void Shell::handleDroppedUrls( const QList<QUrl>& urls )
 {
-    foreach( const QUrl& url, urls )
+    for ( const QUrl &url : urls )
     {
         openUrl( url );
     }
@@ -785,13 +834,13 @@ void Shell::moveTabData( int from, int to )
    m_tabs.move( from, to );
 }
 
-void Shell::slotFitWindowToPage(const QSize& pageViewSize, const QSize& pageSize )
+void Shell::slotFitWindowToPage(const QSize pageViewSize, const QSize pageSize )
 {
     const int xOffset = pageViewSize.width() - pageSize.width();
     const int yOffset = pageViewSize.height() - pageSize.height();
     showNormal();
     resize( width() - xOffset, height() - yOffset);
-    moveSplitter(pageSize.width());
+    emit moveSplitter(pageSize.width());
 }
 
 /* kate: replace-tabs on; indent-width 4; */
