@@ -1,4 +1,4 @@
-/***************************************************************************
+    /***************************************************************************
  *   Copyright (C) 2006 by Chu Xiaodong <xiaodongchu@gmail.com>            *
  *   Copyright (C) 2006 by Pino Toscano <pino@kde.org>                     *
  *   Copyright (C) 2017    Klarälvdalens Datakonsult AB, a KDAB Group      *
@@ -66,7 +66,7 @@ class MovableTitle
     Q_OBJECT
 
 public:
-    MovableTitle( QWidget * parent )
+    MovableTitle( AnnotWindow * parent )
       : QWidget( parent )
     {
         QVBoxLayout * mainlay = new QVBoxLayout( this );
@@ -122,8 +122,8 @@ public:
         latexlay->addWidget( latexButton );
         latexlay->addSpacing( 1 );
         mainlay->addLayout( latexlay );
-        connect(latexButton, SIGNAL(clicked(bool)), parent, SLOT(renderLatex(bool)));
-        connect(parent, SIGNAL(containsLatex(bool)), latexButton, SLOT(setVisible(bool)));
+        connect(latexButton, &QToolButton::clicked, parent, &AnnotWindow::renderLatex);
+        connect(parent, &AnnotWindow::containsLatex, latexButton, &QWidget::setVisible);
 
         titleLabel->installEventFilter( this );
         dateLabel->installEventFilter( this );
@@ -232,7 +232,9 @@ AnnotWindow::AnnotWindow( QWidget * parent, Okular::Annotation * annot, Okular::
     lowerlay->addWidget( sb );
 
     m_latexRenderer = new GuiUtils::LatexRenderer();
-    emit containsLatex( GuiUtils::LatexRenderer::mightContainLatex( m_annot->contents() ) );
+    // The emit below is not wrong even if emitting signals from the constructor it's usually wrong
+    // in this case the signal it's connected to inside MovableTitle constructor a few lines above
+    emit containsLatex( GuiUtils::LatexRenderer::mightContainLatex( m_annot->contents() ) ); // clazy:exclude=incorrect-emit
 
     m_title->setTitle( m_annot->window().summary() );
     m_title->connectOptionButton( this, SLOT(slotOptionBtn()) );
@@ -264,7 +266,7 @@ void AnnotWindow::reloadInfo()
     {
         Okular::TextAnnotation * textAnn = static_cast< Okular::TextAnnotation * >( m_annot );
         if ( textAnn->textType() == Okular::TextAnnotation::InPlace && textAnn->inplaceIntent() == Okular::TextAnnotation::TypeWriter )
-            newcolor = QColor("#fdfd96");
+            newcolor = QColor(0xfd, 0xfd, 0x96);
     }
     if ( !newcolor.isValid() )
         newcolor = m_annot->style().color().isValid() ? QColor(m_annot->style().color().red(), m_annot->style().color().green(), m_annot->style().color().blue(), 255) : Qt::yellow;
@@ -293,7 +295,7 @@ void AnnotWindow::showEvent( QShowEvent * event )
     textEdit->setFocus();
 }
 
-bool AnnotWindow::eventFilter(QObject *, QEvent *e)
+bool AnnotWindow::eventFilter(QObject *o, QEvent *e)
 {
     if ( e->type () == QEvent::ShortcutOverride )
     {
@@ -322,7 +324,7 @@ bool AnnotWindow::eventFilter(QObject *, QEvent *e)
     {
         raise();
     }
-    return false;
+    return QFrame::eventFilter(o, e);
 }
 
 void AnnotWindow::slotUpdateUndoAndRedoInContextMenu(QMenu* menu)
