@@ -57,7 +57,7 @@ class FormWidgetsController : public QObject
 
     public:
         explicit FormWidgetsController( Okular::Document *doc );
-        virtual ~FormWidgetsController();
+        ~FormWidgetsController() override;
 
         void signalAction( Okular::Action *action );
 
@@ -161,6 +161,9 @@ class FormWidgetIface
         FormWidgetIface( QWidget * w, Okular::FormField * ff );
         virtual ~FormWidgetIface();
 
+        FormWidgetIface(const FormWidgetIface &) = delete;
+        FormWidgetIface &operator=(const FormWidgetIface &) = delete;
+
         Okular::NormalizedRect rect() const;
         void setWidthHeight( int w, int h );
         void moveTo( int x, int y );
@@ -269,7 +272,7 @@ class TextAreaEdit : public KTextEdit, public FormWidgetIface
 
     public:
         explicit TextAreaEdit( Okular::FormFieldText * text, QWidget * parent = nullptr );
-        ~TextAreaEdit();
+        ~TextAreaEdit() override;
         void setFormWidgetsController( FormWidgetsController *controller ) override;
         bool event ( QEvent * e ) override;
 
