@@ -58,7 +58,7 @@ Q_OBJECT
 
     public:
         PageView( QWidget *parent, Okular::Document *document );
-        ~PageView();
+        ~PageView() override;
 
         // Zoom mode ( last 4 are internally used only! )
         enum ZoomMode { ZoomFixed = 0, ZoomFitWidth = 1, ZoomFitPage = 2, ZoomFitAuto = 3,
@@ -67,10 +67,10 @@ Q_OBJECT
         enum ClearMode { ClearAllSelection, ClearOnlyDividers };
 
         // create actions that interact with this widget
-        void setupBaseActions( KActionCollection * collection );
-        void setupViewerActions( KActionCollection * collection );
-        void setupActions( KActionCollection * collection );
-        void updateActionState( bool docHasPages, bool docChanged, bool docHasFormWidgets );
+        void setupBaseActions( KActionCollection * ac );
+        void setupViewerActions( KActionCollection * ac );
+        void setupActions( KActionCollection * ac );
+        void updateActionState( bool docHasPages, bool documentChanged, bool docHasFormWidgets );
 
         // misc methods (from RMB menu/children)
         bool canFitPageWidth() const;
@@ -93,8 +93,8 @@ Q_OBJECT
         QVariant capability( ViewCapability capability ) const override;
         void setCapability( ViewCapability capability, const QVariant &option ) override;
 
-        QList< Okular::RegularAreaRect * > textSelections( const QPoint& start, const QPoint& end, int& firstpage );
-        Okular::RegularAreaRect * textSelectionForItem( const PageViewItem * item, const QPoint & startPoint = QPoint(), const QPoint & endPoint = QPoint() );
+        QList< Okular::RegularAreaRect * > textSelections( const QPoint start, const QPoint end, int& firstpage );
+        Okular::RegularAreaRect * textSelectionForItem( const PageViewItem * item, const QPoint startPoint = QPoint(), const QPoint endPoint = QPoint() );
 
         void reparseConfig();
 
@@ -104,8 +104,8 @@ Q_OBJECT
         int contentAreaWidth() const;
         int contentAreaHeight() const;
         QPoint contentAreaPosition() const;
-        QPoint contentAreaPoint( const QPoint & pos ) const;
-        QPointF contentAreaPoint( const QPointF & pos ) const;
+        QPoint contentAreaPoint( const QPoint pos ) const;
+        QPointF contentAreaPoint( const QPointF pos ) const;
 
         bool areSourceLocationsShownGraphically() const;
         void setShowSourceLocationsGraphically(bool show);
@@ -129,12 +129,17 @@ Q_OBJECT
 
         void slotSelectPage();
 
+        void slotAction( Okular::Action *action );
+        void slotFormChanged( int pageNumber );
+
+        void externalKeyPressEvent( QKeyEvent *e );
+
     Q_SIGNALS:
-        void rightClick( const Okular::Page *, const QPoint & );
+        void rightClick( const Okular::Page *, const QPoint );
         void mouseBackButtonClick();
         void mouseForwardButtonClick();
         void escPressed();
-        void fitWindowToPage( const QSize& pageViewPortSize, const QSize& pageSize );
+        void fitWindowToPage( const QSize pageViewPortSize, const QSize pageSize );
         void triggerSearch( const QString& text );
 
     protected:
@@ -162,48 +167,48 @@ Q_OBJECT
 
     private:
         // draw background and items on the opened qpainter
-        void drawDocumentOnPainter( const QRect & pageViewRect, QPainter * p );
+        void drawDocumentOnPainter( const QRect contentsRect, QPainter * p );
         // update item width and height using current zoom parameters
-        void updateItemSize( PageViewItem * item, int columnWidth, int rowHeight );
+        void updateItemSize( PageViewItem * item, int colWidth, int rowHeight );
         // return the widget placed on a certain point or 0 if clicking on empty space
         PageViewItem * pickItemOnPoint( int x, int y );
         // start / modify / clear selection rectangle
-        void selectionStart( const QPoint & pos, const QColor & color, bool aboveAll = false );
+        void selectionStart( const QPoint pos, const QColor & color, bool aboveAll = false );
         void selectionClear( const ClearMode mode = ClearAllSelection );
         void drawTableDividers(QPainter * screenPainter);
         void guessTableDividers();
         // update either text or rectangle selection
-        void updateSelection( const QPoint & pos );
+        void updateSelection( const QPoint pos );
         // compute the zoom factor value for FitWidth and FitPage mode
         double zoomFactorFitMode( ZoomMode mode );
         // update internal zoom values and end in a slotRelayoutPages();
-        void updateZoom( ZoomMode newZm );
+        void updateZoom( ZoomMode newZoomMode );
         // update the text on the label using global zoom value or current page's one
         void updateZoomText();
         // update view mode (single, facing...)
         void updateViewMode ( const int nr );
         void textSelectionClear();
         // updates cursor
-        void updateCursor( const QPoint &p );
+        void updateCursor( const QPoint p );
 
-        void moveMagnifier( const QPoint &p );
-        void updateMagnifier( const QPoint &p );
+        void moveMagnifier( const QPoint p );
+        void updateMagnifier( const QPoint p );
 
         int viewColumns() const;
 
-        void center(int cx, int cy);
-        void scrollTo( int x, int y );
+        void center(int cx, int cy, bool smoothMove = false);
+        void scrollTo( int x, int y, bool smoothMove = false);
 
         void toggleFormWidgets( bool on );
 
-        void resizeContentArea( const QSize & newSize );
+        void resizeContentArea( const QSize newSize );
         void updatePageStep();
 
         void addSearchWithinDocumentAction(QMenu * menu, const QString & searchText );
         void addWebShortcutsMenu( QMenu * menu, const QString & text );
-        QMenu* createProcessLinkMenu( PageViewItem *item, const QPoint & eventPos );
+        QMenu* createProcessLinkMenu( PageViewItem *item, const QPoint eventPos );
         // used when selecting stuff, makes the view scroll as necessary to keep the mouse inside the view
-        void scrollPosIntoView( const QPoint & pos );
+        void scrollPosIntoView( const QPoint pos );
         QPoint viewportToContentArea( const Okular::DocumentViewport & vp ) const;
 
         // called from slots to turn off trim modes mutually exclusive to id
@@ -226,8 +231,6 @@ Q_OBJECT
         void delayedResizeEvent();
         // activated either directly or via the contentsMoving(int,int) signal
         void slotRequestVisiblePixmaps( int newValue = -1 );
-        // activated by the viewport move timer
-        void slotMoveViewport();
         // activated by the autoscroll timer (Shift+Up/Down keys)
         void slotAutoScroll();
         // activated by the dragScroll timer
@@ -259,8 +262,8 @@ Q_OBJECT
         void slotToggleAnnotator( bool );
         void slotAutoScrollUp();
         void slotAutoScrollDown();
-        void slotScrollUp( bool singleStep = false );
-        void slotScrollDown( bool singleStep = false );
+        void slotScrollUp( int nSteps = 0 );
+        void slotScrollDown(int nSteps = 0 );
         void slotRotateClockwise();
         void slotRotateCounterClockwise();
         void slotRotateOriginal();
@@ -268,7 +271,6 @@ Q_OBJECT
         void slotTrimMarginsToggled( bool );
         void slotTrimToSelectionToggled( bool );
         void slotToggleForms();
-        void slotFormChanged( int pageNumber );
         void slotRefreshPage();
 #ifdef HAVE_SPEECH
         void slotSpeakDocument();
@@ -276,8 +278,6 @@ Q_OBJECT
         void slotStopSpeaks();
         void slotPauseResumeSpeech();
 #endif
-        void slotAction( Okular::Action *action );
-        void externalKeyPressEvent( QKeyEvent *e );
         void slotAnnotationWindowDestroyed( QObject *window );
         void slotProcessMovieAction( const Okular::MovieAction *action );
         void slotProcessRenditionAction( const Okular::RenditionAction *action );
